@@ -2,7 +2,7 @@ package AnyEvent::Twitter::Stream;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use AnyEvent;
 use AnyEvent::HTTP;
@@ -14,7 +14,7 @@ use Carp;
 
 our $STREAMING_SERVER  = 'stream.twitter.com';
 our $USERSTREAM_SERVER = 'userstream.twitter.com';
-our $PROTOCOL          = $ENV{'ANYEVENT_TWITTER_STREAM_SSL'} ? 'https' : 'http';
+our $PROTOCOL          = 'https';
 our $US_PROTOCOL       = 'https'; # for testing
 
 my %methods = (
@@ -357,6 +357,8 @@ B<Only with the usertream method>. Callback to execute when the stream send a li
 
 B<Only with the userstream method>. Callback to execute when the stream send an event notification (follow, ...).
 
+=back
+
 =head1 NOTES
 
 To use the B<userstream> method, Twitter recommend using the HTTPS protocol. For this, you need to set the B<ANYEVENT_TWITTER_STREAM_SSL> environment variable, and install the L<Net::SSLeay> module.
